# coding: utf-8

import re


def media_1280_extender(pipeline_index,
                        finder_image_urls,
                        extender_image_urls=[],
                        *args, **kwargs):
    """
    Example:
    http://25.media.tumblr.com/3f5f10d7216f1dd5eacb5eb3e302286a/tumblr_mtpcwdzKBT1qh9n5lo1_250.png
    http://25.media.tumblr.com/3f5f10d7216f1dd5eacb5eb3e302286a/tumblr_mtpcwdzKBT1qh9n5lo1_500.png
    to
    http://25.media.tumblr.com/3f5f10d7216f1dd5eacb5eb3e302286a/tumblr_mtpcwdzKBT1qh9n5lo1_1280.png
    """

    now_extender_image_urls = []

    search_re = re.compile(r'(tumblr_[a-zA-Z0-9_]+)_(\d+).', re.IGNORECASE)

    for image_url in finder_image_urls:
        if 'media.tumblr.com/' in image_url.lower():
            if search_re.search(image_url):
                extender_image_url = search_re.sub(r'\1_1280.', image_url)
                now_extender_image_urls.append(extender_image_url)

    output = {}
    output['extender_image_urls'] = extender_image_urls + now_extender_image_urls

    return output


def avatar_128_extender(pipeline_index,
                        finder_image_urls,
                        extender_image_urls=[],
                        *args, **kwargs):
    """
    Example:
    http://25.media.tumblr.com/avatar_2909d6610c26_16.png
    to
    http://25.media.tumblr.com/avatar_2909d6610c26_128.png
    """

    now_extender_image_urls = []

    search_re = re.compile(r'(avatar_[a-zA-Z0-9_]+)_(\d+).', re.IGNORECASE)

    for image_url in finder_image_urls:
        if 'media.tumblr.com/' in image_url.lower():
            if search_re.search(image_url):
                extender_image_url = search_re.sub(r'\1_128.', image_url)
                now_extender_image_urls.append(extender_image_url)

    output = {}
    output['extender_image_urls'] = extender_image_urls + now_extender_image_urls

    return output



# coding: utf-8

from ...compat import str


def img_src_finder(pipeline_index,
                   soup,
                   finder_image_urls=[],
                   *args, **kwargs):
    """
    Find image URL in <img>'s src attribute
    """

    now_finder_image_urls = []

    for img in soup.find_all('img'):
        src = img.get('src', None)
        if src:
            src = str(src)
            if (src not in finder_image_urls) and \
               (src not in now_finder_image_urls):
                now_finder_image_urls.append(src)

    output = {}
    output['finder_image_urls'] = finder_image_urls + now_finder_image_urls

    return output


def a_href_finder(pipeline_index,
                  soup,
                  finder_image_urls=[],
                  *args, **kwargs):
    """
    Find image URL in <a>'s href attribute
    """

    now_finder_image_urls = []

    for a in soup.find_all('a'):
        href = a.get('href', None)
        if href:
            href = str(href)
            if filter(href.lower().endswith, ('.jpg', '.jpeg', '.gif', '.png')):
              if (href not in finder_image_urls) and \
                 (href not in now_finder_image_urls):
                    now_finder_image_urls.append(href)

    output = {}
    output['finder_image_urls'] = finder_image_urls + now_finder_image_urls

    return output



#!/usr/bin/env python

import os
import sys

from pip.req import parse_requirements

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup


if sys.argv[-1] == 'publish':
    os.system('python setup.py sdist upload')
    sys.exit()

long_description = open('README.rst').read() + '\n\n' + open('HISTORY.rst').read()

license = open('LICENSE').read()

install_requires = [str(item.req) for item in parse_requirements('requirements.txt')]

packages = [
    'haul',
    'haul.finders',
    'haul.finders.pipeline',
    'haul.extenders',
    'haul.extenders.pipeline',
]

setup(
    name='haul',
    version='1.3.0',
    description='An Extensible Image Crawler',
    long_description=long_description,
    keywords='haul web image content scraper parser crawler',
    author='Vinta Chen',
    author_email='vinta.chen@gmail.com',
    url='https://github.com/vinta/Haul',
    license=license,
    install_requires=install_requires,
    include_package_data=True,
    packages=packages,
    zip_safe=False,
    classifiers=(
        'Development Status :: 3 - Alpha',
        'Environment :: Web Environment',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Natural Language :: Chinese (Traditional)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
    ),
)



# coding: utf-8

import re


def original_image_extender(pipeline_index,
                            finder_image_urls,
                            extender_image_urls=[],
                            *args, **kwargs):
    """
    Example:
    http://fashion-fever.nl/wp-content/upload/2013/09/DSC_0058-110x110.jpg
    http://www.wendyslookbook.com/wp-content/uploads/2013/09/Morning-Coffee-Run-7-433x650.jpg
    to
    http://fashion-fever.nl/wp-content/upload/2013/09/DSC_0058.jpg
    http://www.wendyslookbook.com/wp-content/uploads/2013/09/Morning-Coffee-Run-7.jpg
    """

    now_extender_image_urls = []

    check_re = re.compile(r'wp-content/uploads?/', re.IGNORECASE)
    search_re = re.compile(r'(\-\d+x\d+).', re.IGNORECASE)

    for image_url in finder_image_urls:
        if check_re.search(image_url):
            if search_re.search(image_url):
                extender_image_url = search_re.sub('.', image_url)
                now_extender_image_urls.append(extender_image_url)

    output = {}
    output['extender_image_urls'] = extender_image_urls + now_extender_image_urls

    return output



# coding: utf-8

# http://www.crummy.com/software/BeautifulSoup/bs4/doc/#installing-a-parser
DEFAULT_PARSER = 'lxml'

ALLOWED_CONTENT_TYPES = [
    'text/html',
    'image/',
]

FINDER_PIPELINE = (
    'haul.finders.pipeline.html.img_src_finder',
    'haul.finders.pipeline.html.a_href_finder',
    'haul.finders.pipeline.css.background_image_finder',
)

EXTENDER_PIPELINE = (
    'haul.extenders.pipeline.google.blogspot_s1600_extender',
    'haul.extenders.pipeline.google.ggpht_s1600_extender',
    'haul.extenders.pipeline.google.googleusercontent_s1600_extender',
    'haul.extenders.pipeline.pinterest.original_image_extender',
    'haul.extenders.pipeline.wordpress.original_image_extender',
    'haul.extenders.pipeline.tumblr.media_1280_extender',
    'haul.extenders.pipeline.tumblr.avatar_128_extender',
)

SHOULD_JOIN_URL = True
